@@ -1,9 +1,9 @@
-package MooseX::Types; # git description: v0.48-4-gf952a01
-use Moose;
+package MooseX::Types; # git description: v0.50-19-ga14f8fd
+
 # ABSTRACT: Organise your Moose types in libraries
 # KEYWORDS: moose types classes objects constraints declare libraries
 
-our $VERSION = '0.49';
+our $VERSION = '0.51';
 
 use Moose::Util::TypeConstraints      qw( find_type_constraint );
 use MooseX::Types::TypeDecorator;
@@ -12,8 +12,7 @@ use MooseX::Types::Util               qw( filter_tags );
 use MooseX::Types::UndefinedType;
 use MooseX::Types::CheckedUtilExports ();
 use Carp::Clan                        qw( ^MooseX::Types );
-use Sub::Defer                        qw( defer_sub );
-use Sub::Name;
+use Sub::Util                         qw( set_subname );
 use Scalar::Util                      qw( reftype );
 use Sub::Exporter::ForMethods 0.100052 'method_installer';  # for 'rebless'
 
@@ -297,7 +296,7 @@ my $UndefMsg = q{Action for type '%s' not yet defined in library '%s'};
 #pod
 #pod =head1 RECURSIVE SUBTYPES
 #pod
-#pod As of version 0.08, L<Moose::Types> has experimental support for Recursive
+#pod As of version 0.08, L<MooseX::Types> has experimental support for Recursive
 #pod subtypes.  This will allow:
 #pod
 #pod     subtype Tree() => as HashRef[Str|Tree];
@@ -397,7 +396,7 @@ sub type_export_generator {
     ## Return an anonymous subroutine that will generate the proxied type
     ## constraint for you.
 
-    return subname "__TYPE__::$name" => sub {
+    return set_subname "__TYPE__::$name" => sub {
         my $type_constraint = $class->create_base_type_constraint($name);
 
         if(defined(my $params = shift @_)) {
@@ -487,20 +486,17 @@ sub create_type_decorator {
 
 sub coercion_export_generator {
     my ($class, $type, $full, $undef_msg) = @_;
-    return defer_sub undef, sub {
+    return sub {
         my ($value) = @_;
 
         # we need a type object
         my $tobj = find_type_constraint($full) or croak $undef_msg;
+        my $return = $tobj->coerce($value);
 
-        return sub {
-            my $return = $tobj->coerce($_[0]);
+        # non-successful coercion returns false
+        return unless $tobj->check($return);
 
-            # non-successful coercion returns false
-            return unless $tobj->check($return);
-
-            return $return;
-        };
+        return $return;
     }
 }
 
@@ -512,16 +508,13 @@ sub coercion_export_generator {
 
 sub check_export_generator {
     my ($class, $type, $full, $undef_msg) = @_;
-
-    return defer_sub undef, sub {
+    return sub {
         my ($value) = @_;
 
         # we need a type object
         my $tobj = find_type_constraint($full) or croak $undef_msg;
 
-        # This method will actually compile an inlined sub if possible. If
-        # not, it will return something like sub { $tobj->check($_[0]) }
-        return $tobj->_compiled_type_constraint;
+        return $tobj->check($value);
     }
 }
 
@@ -537,7 +530,7 @@ MooseX::Types - Organise your Moose types in libraries
 
 =head1 VERSION
 
-version 0.49
+version 0.51
 
 =head1 SYNOPSIS
 
@@ -812,7 +805,7 @@ type does not yet exist.
 
 =head1 RECURSIVE SUBTYPES
 
-As of version 0.08, L<Moose::Types> has experimental support for Recursive
+As of version 0.08, L<MooseX::Types> has experimental support for Recursive
 subtypes.  This will allow:
 
     subtype Tree() => as HashRef[Str|Tree];
@@ -980,7 +973,7 @@ Robert "phaylon" Sedlacek <rs@474.at>
 
 =head1 CONTRIBUTORS
 
-=for stopwords Karen Etheridge Dave Rolsky John Napiorkowski Robert 'phaylon' Sedlacek Rafael Kitover Florian Ragwitz Matt S Trout Tomas Doran (t0m) Jesse Luehrs Mark Fowler Hans Dieter Pearcey Graham Knop Paul Fenwick Kent Fredric Justin Hunter
+=for stopwords Karen Etheridge Dave Rolsky John Napiorkowski Robert 'phaylon' Sedlacek Rafael Kitover Florian Ragwitz Matt S Trout Graham Knop Hans Dieter Pearcey Jesse Luehrs Mark Fowler Tomas Doran (t0m) Justin Hunter Kent Fredric Paul Fenwick Tadeusz Sośnierz
 
 =over 4
 
@@ -1014,7 +1007,11 @@ Matt S Trout <mst@shadowcat.co.uk>
 
 =item *
 
-Tomas Doran (t0m) <bobtfish@bobtfish.net>
+Graham Knop <haarg@haarg.org>
+
+=item *
+
+Hans Dieter Pearcey <hdp@weftsoar.net>
 
 =item *
 
@@ -1026,15 +1023,11 @@ Mark Fowler <mark@twoshortplanks.com>
 
 =item *
 
-Hans Dieter Pearcey <hdp@weftsoar.net>
+Tomas Doran (t0m) <bobtfish@bobtfish.net>
 
 =item *
 
-Graham Knop <haarg@haarg.org>
-
-=item *
-
-Paul Fenwick <pjf@perltraining.com.au>
+Justin Hunter <justin.d.hunter@gmail.com>
 
 =item *
 
@@ -1042,7 +1035,11 @@ Kent Fredric <kentfredric@gmail.com>
 
 =item *
 
-Justin Hunter <justin.d.hunter@gmail.com>
+Paul Fenwick <pjf@perltraining.com.au>
+
+=item *
+
+Tadeusz Sośnierz <tadeusz.sosnierz@onet.pl>
 
 =back
 
